@@ -23,7 +23,7 @@ class IntegrationTest extends IntegrationTestCase
         ];
     }
 
-    public function getFixturesDir()
+    protected static function getFixturesDirectory(): string
     {
         return __DIR__.'/Fixtures/';
     }
